%define maj  4
%define min  1
%define rel  25
%define sov  %{maj}.%{min}

Summary:     Berkeley DB database library (version 4)
Name:        db4
Version:     %{maj}.%{min}.%{rel}
Release:     3.pp
License:     GPL
Group:       System Environment/Libraries
Source0:     http://www.sleepycat.com/update/snapshot/db-%{version}.tar.gz
Patch0:      http://www.sleepycat.com/update/%{version}/patch.%{version}.1
URL:         http://www.sleepycat.com/
Buildroot:   /var/tmp/%{name}-root
Vendor:      Peter Pramberger
Packager:    Peter Pramberger <peter.pramberger@1012surf.net>
Provides:    %{name}.pp
Prereq:      /bin/bash /sbin/ldconfig
BuildPrereq: gcc >= 2.96 /bin/mkdir /usr/bin/make /usr/bin/install
BuildPrereq: perl tcl libtool
ExclusiveOS: linux

%description
The Berkeley Database (Berkeley DB) is a programmatic toolkit
that provides embedded database support for both traditional and
client/server applications. The Berkeley DB includes B+tree, Extended
Linear Hashing, Fixed and Variable-length record access methods,
transactions, locking, logging, shared memory caching, and database
recovery. The Berkeley DB supports C, C++, Java, and Perl APIs. It is
used by many applications, including Python and Perl, so this should
be installed on all systems.


%package devel
Summary:     Development files for the Berkeley DB (version 4) library
Group:       Development/Libraries
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-devel.pp
Conflicts:   db4-devel < %{version}

%package utils
Summary:     Command line tools for managing Berkeley DB (version 4) databases
Group:       Applications/Databases
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-utils.pp
Conflicts:   db4-utils < %{version}


%description devel
This package contains the header files, libraries, and documentation
for building programs which use the Berkeley DB.

%description utils
This package contains command line tools for managing Berkeley DB
(version 4) databases.


%prep
%setup -q -n db-%{version}
%patch0 -p0
# Define a shell function for fixing HREF references in the docs, which
# would otherwise break when we split the docs up into subpackages.
fixup_href() {
   for doc in $@ ; do
      chmod u+w ${doc}
      sed -e 's,="../api_c/,="../../%{name}-devel-%{version}/api_c/,g'               \
	  -e 's,="api_c/,="../%{name}-devel-%{version}/api_c/,g'                     \
	  -e 's,="../api_cxx/,="../../%{name}-devel-%{version}/api_cxx/,g'           \
	  -e 's,="api_cxx/,="../%{name}-devel-%{version}/api_cxx/,g'                 \
	  -e 's,="../api_java/,="../../%{name}-devel-%{version}/api_java/,g'         \
	  -e 's,="api_java/,="../%{name}-devel-%{version}/api_java/,g'               \
	  -e 's,="../api_tcl/,="../../%{name}-devel-%{version}/api_tcl/,g'           \
	  -e 's,="api_tcl/,="../%{name}-devel-%{version}/api_tcl/,g'                 \
	  -e 's,="../examples_c/,="../../%{name}-devel-%{version}/examples_c/,g'     \
	  -e 's,="examples_c/,="../%{name}-devel-%{version}/examples_c/,g'           \
	  -e 's,="../examples_cxx/,="../../%{name}-devel-%{version}/examples_cxx/,g' \
	  -e 's,="examples_cxx/,="../%{name}-devel-%{version}/examples_cxx/,g'       \
	  -e 's,="../ref/,="../../%{name}-devel-%{version}/ref/,g'                   \
	  -e 's,="ref/,="../%{name}-devel-%{version}/ref/,g'                         \
	  -e 's,="../sleepycat/,="../../%{name}-devel-%{version}/sleepycat/,g'       \
	  -e 's,="sleepycat/,="../%{name}-devel-%{version}/sleepycat/,g'             \
	  -e 's,="../images/,="../../%{name}-%{version}/images/,g'                   \
	  -e 's,="images/,="../%{name}-%{version}/images/,g'                         \
	  -e 's,="../utility/,="../../%{name}-utils-%{version}/utility/,g'           \
	  -e 's,="utility/,="../%{name}-utils-%{version}/utility/,g' ${doc} > ${doc}.new
      touch -r ${doc} ${doc}.new
      cat ${doc}.new > ${doc}
      touch -r ${doc}.new ${doc}
      rm -f ${doc}.new
   done
}
                                                                                                         
set +x  # XXX painful to watch
# Fix all of the HTML files.
fixup_href `find . -name "*.html"`
set -x  # XXX painful to watch


%build
CFLAGS="$RPM_OPT_FLAGS"
export CFLAGS
cd build_unix
../dist/configure \
	--prefix=/usr           \
	--sysconfdir=/etc       \
	--localstatedir=/var    \
	--mandir=/usr/share/man \
	--enable-cxx            \
	--enable-rpc            \
	--enable-tcl            \
	--enable-shared         \
	--enable-static         \
	--enable-test           \
	--disable-posixmutexes  \
	--with-tcl=/usr/lib
make


%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/include/%{name}

cd build_unix
make prefix=$RPM_BUILD_ROOT/usr install

chmod +x $RPM_BUILD_ROOT/usr/lib/*.so*

# Move the header files to a subdirectory, in case we're deploying on a
# system with multiple versions of DB installed.
mv $RPM_BUILD_ROOT/usr/include/*.h $RPM_BUILD_ROOT/usr/include/%{name}

# Rename the utilities s/db_/dbN_/ (for multiple versions of DB installed)
for p in \
   berkeley_db_svc \
   db_archive      \
   db_checkpoint   \
   db_deadlock     \
   db_dump         \
   db_load         \
   db_printlog     \
   db_recover      \
   db_stat         \
   db_upgrade      \
   db_verify       \
   ; do
      q="`echo $p | sed -e 's,db_,%{name}_,'`"
      mv ${RPM_BUILD_ROOT}/usr/bin/$p ${RPM_BUILD_ROOT}/usr/bin/$q
done

# Create symlinks to includes so that "use <db.h> and link with -ldb" works.
for i in \
   cxx_common.h \
   cxx_except.h \
   db_cxx.h     \
   db.h         \
   ; do
      ln -s db4/$i $RPM_BUILD_ROOT/usr/include
done

# Eliminate installed doco
rm -rf ${RPM_BUILD_ROOT}/usr/docs


%post
/sbin/ldconfig


%postun
/sbin/ldconfig


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc LICENSE README docs/images
/usr/lib/libdb-%{sov}.so
/usr/lib/libdb_cxx-%{sov}.so
/usr/lib/libdb_tcl-%{sov}.so

%files devel
%defattr(-,root,root)
%doc docs/api_c docs/api_cxx docs/api_tcl docs/index.html
%doc docs/ref docs/sleepycat
%doc examples_c examples_cxx
%dir /usr/include/%{name}
/usr/include/%{name}/*
/usr/include/*.h
/usr/lib/libdb.so
/usr/lib/libdb_cxx.so
/usr/lib/libdb_tcl.so
/usr/lib/libdb-%{maj}.so
/usr/lib/libdb_cxx-%{maj}.so
/usr/lib/libdb_tcl-%{maj}.so
/usr/lib/*.*a

%files utils
%defattr(-,root,root)
%doc docs/utility
/usr/bin/*


%changelog
* Mon Feb 09 2004 peter.pramberger@1012surf.net
- disable NTPL support (not really working with 2.4 kernels)

* Fri Feb 06 2004 peter.pramberger@1012surf.net
- created

